Contains lower-level structs to handle the multistream protocol.

Structs

Wraps around a AsyncRead+AsyncWrite. Assumes that we’re on the dialer’s side. Produces and accepts messages.
Future, returned by Dialer::new, which send the handshake and returns the actual Dialer.
Wraps around a AsyncRead+AsyncWrite. Assumes that we’re on the listener’s side. Produces and accepts messages.
Future, returned by Listener::new which performs the handshake and returns the Listener if successful.

Enums

Message sent from the dialer to the listener.
Message sent from the listener to the dialer.
Error at the multistream-select layer of communication.