pub enum DialerToListenerMessage<N> {
    ProtocolRequest {
        name: N,
    },
    ProtocolsListRequest,
}
Message sent from the dialer to the listener.

Variants

ProtocolRequest

Fields

name: N

Name of the protocol.

The dialer wants us to use a protocol.

If this is accepted (by receiving back a ProtocolAck), then we immediately start communicating in the new protocol.

ProtocolsListRequest

The dialer requested the list of protocols that the listener supports.